@@ -1,48 +1,59 @@
 import os
 import sys
 import glob
-import argparse
 import json
 import tempfile
+from typing import Optional, Dict, List
 
-import hpogrid
-
-from hpogrid.components.defaults import *
+from hpogrid import semistaticmethod
+from hpogrid.core.defaults import *
+from hpogrid.core import config_manager
 from hpogrid.utils import helper, stylus
-from hpogrid.idds_interface.idds_utils import transpose_config
-from hpogrid.configuration import ProjectConfiguration
 
-class GridHandler():
+from .abstract_object import AbstractObject
+
+class GridHandler(AbstractObject):
     
-    @staticmethod
-    def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid', debug=False, extra=[]):
-        config = GridHandler.preprocess_config(config_input)
+    def __init__(self, verbosity:str="INFO"):
+        super().__init__(verbosity=verbosity)
+    
+    @semistaticmethod
+    def submit(self, config_input:str, n_jobs:int=1, site:str=None, time:int=-1, search_points:List=None,
+               mode:str='grid', debug:bool=False, scripts_path:str=None, extra:Optional[Dict]=None):
+        if extra is None:
+            extra = []
+        config = self.preprocess_config(config_input, scripts_path)
         if mode == 'grid':
-            GridHandler.submit_grid(config, n_jobs=n_jobs, site=site,
-                                    time=time, search_points=search_points, debug=debug, extra=extra)
+            self.submit_grid(config, n_jobs=n_jobs, site=site, time=time,
+                             search_points=search_points, debug=debug, extra=extra)
         elif mode == 'idds':
-            GridHandler.submit_idds(config, n_jobs=n_jobs, site=site, debug=debug, extra=extra)
+            self.submit_idds(config, n_jobs=n_jobs, site=site, debug=debug, extra=extra)
         else:
             raise ValueError('Unknown job submission mode: {}'.format(mode))
             
-    @staticmethod
-    def preprocess_config(config_input):
-        config = hpogrid.load_configuration(config_input)
+    @semistaticmethod
+    def preprocess_config(self, config_input:str, scripts_path:str=None):
+        config = config_manager.load_configuration(config_input)
+        from hpogrid.configuration import ProjectConfiguration
         config = ProjectConfiguration._validate(config)
         project_name = config['project_name']
-        if not helper.is_project(project_name):
-            print('INFO: Creating project directory for "{}"'.format(project_name))
-            hpogrid.create_project(config, 'create')
-        elif not helper.is_project(config_input):
-            print('INFO: Replacing project directory for "{}"'.format(project_name))
-            hpogrid.create_project(config, 'recreate')
+        if not config_manager.is_project(project_name):
+            self.stdout.info(f'INFO: Creating project directory for "{project_name}"')
+            ProjectConfiguration.create_project(config, scripts_path=scripts_path, action='create')
+        elif not config_manager.is_project(config_input):
+            self.stdout.info(f'INFO: Replacing project directory for "{project_name}"')
+            ProjectConfiguration.create_project(config, scripts_path=scripts_path, action='recreate')
         return config
         
-    @staticmethod
-    def submit_idds(config, n_jobs=1, site=None, debug=False, extra=[]):
-        project_path = helper.get_project_path(config['project_name'])
-        print('INFO: Submitting {} idds grid job(s)'.format(n_jobs))
+    @semistaticmethod
+    def submit_idds(self, config:Dict, n_jobs:int=1, site:str=None, debug:bool=False,
+                    extra:Optional[Dict]=None):
+        if extra is None:
+            extra = []
+        project_path = config_manager.get_project_path(config['project_name'])
+        self.stdout.info(f'INFO: Submitting {n_jobs} idds grid job(s)')
         with tempfile.TemporaryDirectory() as tmpdirname:
+            from hpogrid.interface.idds.main import transpose_config
             idds_config, search_space = transpose_config(config)
             idds_config_path = os.path.join(tmpdirname, 'idds_config.json')
             search_space_path = os.path.join(tmpdirname, 'search_space.json')
@@ -51,38 +62,38 @@ class GridHandler():
                 json.dump(idds_config, idds_config_file)
             with open(search_space_path, 'w') as search_space_file:
                 json.dump(search_space, search_space_file)  
-            command = GridHandler.format_idds_command(config, 
-                                               tmpdirname,
-                                               site=site,
-                                               extra=extra)
+            command = self.format_idds_command(config, tmpdirname, site=site, extra=extra)
             with helper.cd(project_path):
                 if debug:
-                    print('INFO: iDDS configuration is')
+                    self.stdout.info('INFO: iDDS configuration is')
                     table = stylus.create_formatted_dict(idds_config, ['Attribute', 'Value'], indexed=False)
-                    print(table)
+                    self.stdout.info(table)
                     # submit jobs
-                    print('INFO: The idds command is ')
-                    print('{}'.format(command))
+                    self.stdout.info('INFO: The idds command is ')
+                    self.stdout.info(f'{command}')
                 for _ in range(n_jobs):
                     os.system(command)
-    @staticmethod
-    def submit_grid(config, n_jobs=1, site=None, time=-1, search_points=None, debug=False, extra=[]):
-        project_path = helper.get_project_path(config['project_name'])
-        print('INFO: Submitting {} grid job(s)'.format(n_jobs))
-        command = GridHandler.format_grid_command(config, site=site,
-                                                  time=time,
-                                                  search_points=search_points,
-                                                  extra=extra)
+    @semistaticmethod
+    def submit_grid(self, config:Dict, n_jobs:int=1, site:str=None, time:int=-1, debug:bool=False,
+                    search_points:List=None, scripts_path:str=None, extra:Optional[Dict]=None):
+        if extra is None:
+            extra = []
+        project_path = config_manager.get_project_path(config['project_name'])
+        print(f'INFO: Submitting {n_jobs} grid job(s)')
+        command = self.format_grid_command(config, site=site, time=time,
+                                           search_points=search_points,  extra=extra)
         with helper.cd(project_path):
             # submit jobs
             for _ in range(n_jobs):
                 if debug:
-                    print('INFO: The prun command is ')
-                    print('{}'.format(command))                
+                    self.stdout.info('INFO: The prun command is ')
+                    self.stdout.info(f'{command}')
                 os.system(command)
                 
     @staticmethod
-    def format_idds_command(config, tmpdirname, site=None, extra=[]):
+    def format_idds_command(config:Dict, tmpdirname:str, site:str=None, extra:Optional[Dict]=None):
+        if extra is None:
+            extra = []
         idds_config_path = os.path.join(tmpdirname, 'idds_config.json')
         search_space_path = os.path.join(tmpdirname, 'search_space.json')
         options = {'loadJson': idds_config_path,
@@ -120,7 +131,10 @@ class GridHandler():
         return command
     
     @staticmethod
-    def format_grid_command(config, site=None, time=-1, search_points=None, extra=[]):
+    def format_grid_command(config:Dict, site:str=None, time:int=-1,
+                            search_points:List=None, extra:Optional[Dict]=None):
+        if extra is None:
+            extra = []
         options = {'forceStaged': '',
                    'useSandbox': '',
                    'noBuild': '',
