@@ -15,14 +15,15 @@ class SkOptGenerator(Generator):
         self.labels = [hp.name for hp in search_space]
         return searcher
 
-    def ask(self, n_points:int = None):
+    def _ask(self, searcher, n_points:int = None):
         points = []
         for _ in range(n_points):
-            point = self.searcher.ask()
+            point = searcher.ask()
             point = dict(zip(self.labels, point))
             points.append(copy.deepcopy(point))
         return points
 
-    def tell(self, point:Dict, value):
+    def _tell(self, searcher, point:Dict, value):
         value = self._to_metric_values(value)
-        self.searcher.tell(point, self.signature * value)
+        x = [point[label] for label in self.labels]
+        searcher.tell(x, self.signature * value)
