@@ -2,6 +2,7 @@ import os
 import sys
 import json
 import shutil
+import numbers
 import inspect
 import tarfile
 from typing import List, Dict
@@ -11,6 +12,20 @@ import shlex
 
 import numpy as np
 
+def old_div(a, b):
+    """
+    DEPRECATED: import ``old_div`` from ``past.utils`` instead.
+
+    Equivalent to ``a / b`` on Python 2 without ``from __future__ import
+    division``.
+
+    TODO: generalize this to other objects (like arrays etc.)
+    """
+    if isinstance(a, numbers.Integral) and isinstance(b, numbers.Integral):
+        return a // b
+    else:
+        return a / b
+
 def run_command(cmd):
     args = shlex.split(cmd, posix=False)
     with Popen(args, stdout=PIPE, bufsize=1, universal_newlines=True) as p:
