@@ -1,12 +1,12 @@
 """
     Module for formatting tables, texts and figures used in hpogrid
 """
-
-from tabulate import tabulate
-import pandas as pd
 import yaml
 import copy
 
+import pandas as pd
+from tabulate import tabulate
+
 kDefaultTableStyle = 'psql'
 kDefaultStrAlign = 'left'
 
@@ -22,7 +22,19 @@ class ColorCode():
     UNDERLINE = '\033[4m'
     BLINK = '\033[5m'
     
+def str_presenter(dumper, data):
+    """configures yaml for dumping multiline strings
+    Ref: https://stackoverflow.com/questions/8640959/how-can-i-control-what-scalar-form-pyyaml-uses-for-my-data"""
+    if len(data.splitlines()) > 1:  # check for multiline string
+        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
+    return dumper.represent_scalar('tag:yaml.org,2002:str', data)
+
+yaml.add_representer(str, str_presenter)
+yaml.representer.SafeRepresenter.add_representer(str, str_presenter)    
     
+def insert_newlines(string, every=64):
+    return '\n'.join(string[i:i+every] for i in range(0, len(string), every))
+
 def type2str(typevar):
     if isinstance(typevar, tuple):
         return ', '.join([t.__name__ for t in typevar])
@@ -42,9 +54,20 @@ def create_table(data, columns=None, indexed=True, transpose=False,
         stralign=stralign)
     return table
 
+def format_dict_str_len(source):
+    if isinstance(source, dict):
+        for key, value in source.items():
+            source[key] = format_dict_str_len(value)
+        return source
+    elif isinstance(source, str) and (len(source) > 80):
+        return insert_newlines(source, 80)
+    else:
+        return source
+
 def create_formatted_dict(data, columns=None, indexed=True, transpose=False,
     tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign):
     _data = copy.deepcopy(data)
+    _data = format_dict_str_len(_data)  
     if isinstance(_data, dict):
         for key in _data:
             if isinstance(_data[key], dict):
